@@ -17,10 +17,10 @@
 # limitations under the License.
 
 # project name
-SERVER_NAME="apache-hertzbeat-1.6.1"
+SERVER_NAME="apache-hertzbeat-1.7.0"
 
 # jar name
-JAR_NAME="apache-hertzbeat-1.6.1.jar"
+JAR_NAME="apache-hertzbeat-1.7.0.jar"
 
 # cd bin
 cd `dirname $0`
@@ -47,7 +47,7 @@ fi
 
 # JVM Configuration
 if [ -z "$JAVA_OPTS" ]; then
-  JAVA_OPTS=" -Doracle.jdbc.timezoneAsRegion=false"
+  JAVA_OPTS=" -Doracle.jdbc.timezoneAsRegion=false --add-opens=java.base/java.nio=org.apache.arrow.memory.core,ALL-UNNAMED"
 else
   JAVA_OPTS="${JAVA_OPTS} -Doracle.jdbc.timezoneAsRegion=false"
 fi
